@@ -122,6 +122,9 @@ def main(argv):
     from quodlibet.plugins.playlist import PLAYLIST_HANDLER
     PLAYLIST_HANDLER.init_plugins()
 
+    from quodlibet.plugins.query import QUERY_HANDLER
+    QUERY_HANDLER.init_plugins()
+
     from gi.repository import GLib
 
     def exec_commands(*args):
@@ -134,7 +137,7 @@ def main(argv):
                 if resp is not None:
                     print_(resp, end="")
 
-    from quodlibet.qltk.quodlibetwindow import QuodLibetWindow
+    from quodlibet.qltk.quodlibetwindow import QuodLibetWindow, PlayerOptions
     # Call exec_commands after the window is restored, but make sure
     # it's after the mainloop has started so everything is set up.
     app.window = window = QuodLibetWindow(
@@ -142,6 +145,8 @@ def main(argv):
         restore_cb=lambda:
             GLib.idle_add(exec_commands, priority=GLib.PRIORITY_HIGH))
 
+    app.player_options = PlayerOptions(window)
+
     from quodlibet.qltk.debugwindow import MinExceptionDialog
     from quodlibet.qltk.window import on_first_map
     if backend_traceback is not None:
@@ -169,9 +174,9 @@ def main(argv):
     except ImportError:
         DBusHandler = lambda player, library: None
 
-    mmkeys_handler = MMKeysHandler(app.name, window, player)
-    if "QUODLIBET_NO_MMKEYS" not in os.environ:
-        mmkeys_handler.start()
+    mmkeys_handler = MMKeysHandler(app)
+    mmkeys_handler.start()
+
     current_path = os.path.join(quodlibet.get_user_dir(), "current")
     fsiface = FSInterface(current_path, player)
     remote = Remote(app, cmd_registry)
@@ -208,6 +213,7 @@ def main(argv):
 
     quodlibet.main(window, before_quit=before_quit)
 
+    app.player_options.destroy()
     quodlibet.finish_first_session(app.id)
     mmkeys_handler.quit()
     remote.stop()
