@@ -8,10 +8,12 @@
 # published by the Free Software Foundation
 
 import os
-from cStringIO import StringIO
+
+from quodlibet.util.string import split_escape
 
 from quodlibet import browsers
 
+from quodlibet.compat import cBytesIO as StringIO
 from quodlibet import util
 from quodlibet.util.uri import URI
 from quodlibet.util.path import fsnative
@@ -252,11 +254,8 @@ def _dump_browsers(app):
 
 @registry.register("set-browser", args=1)
 def _set_browser(app, value):
-    try:
-        browsers.get(value)
-    except ValueError:
+    if not app.window.select_browser(value, app.library, app.player):
         raise CommandError("Unknown browser %r" % value)
-    app.window.select_browser(None, value, app.library, app.player)
 
 
 @registry.register("open-browser", args=1)
@@ -332,12 +331,13 @@ def _enqueue(app, value):
 
 @registry.register("enqueue-files", args=1)
 def _enqueue_files(app, value):
-    """Enqueues comma-separated filenames or song names."""
+    """Enqueues comma-separated filenames or song names.
+    Commas in filenames should be backslash-escaped"""
 
     library = app.library
     window = app.window
     songs = []
-    for param in value.split(","):
+    for param in split_escape(value, ","):
         try:
             song_path = URI(param).filename
         except ValueError:
