@@ -8,7 +8,7 @@
 
 import os
 
-from gi.repository import Gtk, Gdk, GLib, Gio
+from gi.repository import Gtk, Gdk, GLib, Gio, GObject
 
 import quodlibet
 
@@ -27,6 +27,7 @@ from quodlibet.qltk.controls import PlayControls
 from quodlibet.qltk.cover import CoverImage
 from quodlibet.qltk.getstring import GetStringDialog
 from quodlibet.qltk.bookmarks import EditBookmarks
+from quodlibet.qltk.shortcuts import show_shortcuts
 from quodlibet.qltk.info import SongInfo
 from quodlibet.qltk.information import Information
 from quodlibet.qltk.msg import ErrorMessage, WarningMessage
@@ -39,10 +40,10 @@ from quodlibet.qltk.queue import QueueExpander
 from quodlibet.qltk.songlist import SongList, get_columns, set_columns
 from quodlibet.qltk.songmodel import PlaylistMux
 from quodlibet.qltk.x import ConfigRVPaned, Align, ScrolledWindow, Action
-from quodlibet.qltk.x import SymbolicIconImage, CellRendererPixbuf, \
-    ToggleAction, RadioAction
+from quodlibet.qltk.x import SymbolicIconImage, ToggleAction, RadioAction
+from quodlibet.qltk.x import SeparatorMenuItem, MenuItem, CellRendererPixbuf
 from quodlibet.qltk import Icons
-from quodlibet.qltk.about import AboutQuodLibet
+from quodlibet.qltk.about import AboutDialog
 from quodlibet.util import copool, connect_destroy, connect_after_destroy
 from quodlibet.util.library import get_scan_dirs, set_scan_dirs
 from quodlibet.util.uri import URI
@@ -53,6 +54,166 @@ from quodlibet.qltk.window import PersistentWindowMixin, Window, on_first_map
 from quodlibet.qltk.songlistcolumns import SongListColumn
 
 
+class PlayerOptions(GObject.Object):
+    """Provides a simplified interface for playback options.
+
+    This currently provides a limited view on the play order state which is
+    useful for external interfaces (mpd, mpris, etc.) and for reducing
+    the dependency on the state holding widgets in the main window.
+
+    Usable as long as the main window is not destroyed, or until `destroy()`
+    is called.
+    """
+
+    __gproperties__ = {
+        'random': (bool, '', '', False,
+                   GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE),
+        'repeat': (bool, '', '', False,
+                   GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE),
+        'single': (bool, '', '', False,
+                   GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE),
+        'stop-after': (
+            bool, '', '', False,
+            GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE),
+    }
+
+    def __init__(self, window):
+        """windows is a QuodLibetWindow"""
+
+        super(PlayerOptions, self).__init__()
+
+        self._repeat = window.repeat
+        self._rid = self._repeat.connect(
+            "toggled", lambda *x: self.notify("repeat"))
+
+        self._stop_after = window.stop_after
+        self._said = self._stop_after.connect(
+            "toggled", lambda *x: self.notify("stop-after"))
+
+        def order_changed(*args):
+            self.notify("random")
+            self.notify("single")
+
+        self._order = window.order
+        self._oid = self._order.connect("changed", order_changed)
+
+        window.connect("destroy", self._window_destroy)
+
+    def _window_destroy(self, window):
+        self.destroy()
+
+    def destroy(self):
+        if self._repeat:
+            self._repeat.disconnect(self._rid)
+            self._repeat = None
+        if self._order:
+            self._order.disconnect(self._oid)
+            self._order = None
+        if self._stop_after:
+            self._stop_after.disconnect(self._said)
+            self._stop_after = None
+
+    def do_get_property(self, param):
+        return getattr(self, param.name.replace("-", "_"))
+
+    def do_set_property(self, param, value):
+        setattr(self, param.name.replace("-", "_"), value)
+
+    @property
+    def single(self):
+        """If only the current song is considered as next track
+
+        When `repeat` is False the playlist will end after this song finishes.
+        When `repeat` is True the current song will be replayed.
+        """
+
+        return self._order.get_active_name() == "onesong"
+
+    @single.setter
+    def single(self, value):
+        if value and not self.single:
+            self._order.set_active_by_name("onesong")
+        elif not value and self.single:
+            self._order.set_active_by_name("inorder")
+
+    @property
+    def random(self):
+        """If a random based play order is active"""
+
+        return self._order.get_shuffle()
+
+    @random.setter
+    def random(self, value):
+        self._order.set_shuffle(value)
+
+    @property
+    def repeat(self):
+        """If the playlist will be restarted if it ended"""
+
+        return self._repeat.get_active()
+
+    @repeat.setter
+    def repeat(self, value):
+        self._repeat.set_active(value)
+
+    @property
+    def stop_after(self):
+        """If the player will pause after the current song ends"""
+
+        return self._stop_after.get_active()
+
+    @stop_after.setter
+    def stop_after(self, value):
+        self._stop_after.set_active(value)
+
+
+class DockMenu(Gtk.Menu):
+    """Menu used for the OSX dock and the tray icon"""
+
+    def __init__(self, app):
+        super(DockMenu, self).__init__()
+
+        player = app.player
+
+        play_item = MenuItem(_("_Play"), Icons.MEDIA_PLAYBACK_START)
+        play_item.connect("activate", self._on_play, player)
+        pause_item = MenuItem(_("P_ause"), Icons.MEDIA_PLAYBACK_PAUSE)
+        pause_item.connect("activate", self._on_pause, player)
+        self.append(play_item)
+        self.append(pause_item)
+
+        previous = MenuItem(_("Pre_vious"), Icons.MEDIA_SKIP_BACKWARD)
+        previous.connect('activate', lambda *args: player.previous())
+        self.append(previous)
+
+        next_ = MenuItem(_("_Next"), Icons.MEDIA_SKIP_FORWARD)
+        next_.connect('activate', lambda *args: player.next())
+        self.append(next_)
+
+        browse = qltk.MenuItem(_("_Browse Library"), Icons.EDIT_FIND)
+        browse_sub = Gtk.Menu()
+        for Kind in browsers.browsers:
+            if Kind.is_empty:
+                continue
+            i = Gtk.MenuItem(label=Kind.accelerated_name, use_underline=True)
+            connect_obj(i,
+                'activate', LibraryBrowser.open, Kind, app.library, app.player)
+            browse_sub.append(i)
+
+        browse.set_submenu(browse_sub)
+        self.append(SeparatorMenuItem())
+        self.append(browse)
+
+        self.show_all()
+        self.hide()
+
+    def _on_play(self, item, player):
+        player.paused = False
+
+    def _on_pause(self, item, player):
+        player.paused = True
+
+
 class CurrentColumn(SongListColumn):
     """Displays the current song indicator, either a play or pause icon."""
 
@@ -101,7 +262,7 @@ class CurrentColumn(SongListColumn):
 
 
 class MainSongList(SongList):
-    # The SongList that represents the current playlist.
+    """SongList for the main browser's displayed songs."""
 
     _activated = False
 
@@ -173,10 +334,13 @@ class TopBar(Gtk.Toolbar):
         info_item.add(box)
         qltk.add_css(self, "GtkToolbar {padding: 3px;}")
 
+        self._pattern_box = Gtk.VBox()
+
         # song text
         info_pattern_path = os.path.join(quodlibet.get_user_dir(), "songinfo")
         text = SongInfo(library.librarian, player, info_pattern_path)
-        box.pack_start(Align(text, border=3), True, True, 0)
+        self._pattern_box.pack_start(Align(text, border=3), True, True, 0)
+        box.pack_start(self._pattern_box, True, True, 0)
 
         # cover image
         self.image = CoverImage(resize=True)
@@ -201,6 +365,14 @@ class TopBar(Gtk.Toolbar):
         context = self.get_style_context()
         context.add_class("primary-toolbar")
 
+    def set_seekbar_widget(self, widget):
+        children = self._pattern_box.get_children()
+        if len(children) > 1:
+            self._pattern_box.remove(children[-1])
+
+        if widget:
+            self._pattern_box.pack_start(widget, False, True, 0)
+
     def _on_volume_changed(self, player, *args):
         config.set("memory", "volume", str(player.volume))
 
@@ -220,10 +392,10 @@ class TopBar(Gtk.Toolbar):
             library.albums.refresh(refresh_albums)
 
 
-class ReapeatButton(Gtk.ToggleButton):
+class RepeatButton(Gtk.ToggleButton):
 
     def __init__(self):
-        super(ReapeatButton, self).__init__(
+        super(RepeatButton, self).__init__(
             image=SymbolicIconImage(
                 "media-playlist-repeat", Gtk.IconSize.SMALL_TOOLBAR))
 
@@ -256,7 +428,7 @@ class StatusBarBox(Gtk.HBox):
         self.order = order = PlayOrder(model, player)
         self.pack_start(order, False, True, 0)
 
-        self.repeat = repeat = ReapeatButton()
+        self.repeat = repeat = RepeatButton()
         self.pack_start(repeat, False, True, 0)
         repeat.connect('toggled', self.__repeat, model)
         model.repeat = repeat.get_active()
@@ -440,6 +612,7 @@ MENU = """
     </menu>
     <menu action='Help'>
       <menuitem action='OnlineHelp' always-show-image='true'/>
+      <menuitem action='Shortcuts' always-show-image='true'/>
       <menuitem action='SearchHelp' always-show-image='true'/>
       <menuitem action='About' always-show-image='true'/>
     </menu>
@@ -607,7 +780,7 @@ class QuodLibetWindow(Window, PersistentWindowMixin):
 
         restore_browser = not headless
         try:
-            self.select_browser(
+            self._select_browser(
                 self, config.get("memory", "browser"), library, player,
                 restore_browser)
         except:
@@ -645,9 +818,21 @@ class QuodLibetWindow(Window, PersistentWindowMixin):
 
         self.enable_window_tracking("quodlibet")
 
+    def set_seekbar_widget(self, widget):
+        """Add an alternative seek bar widget.
+
+        Args:
+            widget (Gtk.Widget): a new widget or None to remove the current one
+        """
+
+        self.top_bar.set_seekbar_widget(widget)
+
     def set_as_osx_window(self, osx_app):
         assert osx_app
 
+        self._dock_menu = DockMenu(app)
+        osx_app.set_dock_menu(self._dock_menu)
+
         menu = self.ui.get_widget("/Menu")
         menu.hide()
         osx_app.set_menu_bar(menu)
@@ -693,6 +878,9 @@ class QuodLibetWindow(Window, PersistentWindowMixin):
                 bookmarks.append(new_mark)
                 player.song.bookmarks = bookmarks
 
+    def __keyboard_shortcuts(self, action):
+        show_shortcuts(self)
+
     def __edit_bookmarks(self, librarian, player):
         if player.song:
             window = EditBookmarks(self, librarian, player)
@@ -890,9 +1078,13 @@ class QuodLibetWindow(Window, PersistentWindowMixin):
                            library.librarian, player)
         ag.add_action_with_accel(act, "<Primary>B")
 
+        act = Action(name="Shortcuts", label=_("_Keyboard Shortcuts"))
+        act.connect('activate', self.__keyboard_shortcuts)
+        ag.add_action_with_accel(act, "<Primary>F1")
+
         act = Action(name="About", label=_("_About"),
                      icon_name=Icons.HELP_ABOUT)
-        connect_obj(act, 'activate', self.__show_about, player)
+        act.connect('activate', self.__show_about)
         ag.add_action_with_accel(act, None)
 
         act = Action(name="OnlineHelp", label=_("Online Help"),
@@ -913,7 +1105,7 @@ class QuodLibetWindow(Window, PersistentWindowMixin):
         ag.add_action_with_accel(act, None)
 
         act = Action(
-            name="RefreshLibrary", label=_("Re_fresh Library"),
+            name="RefreshLibrary", label=_("_Scan Library"),
             icon_name=Icons.VIEW_REFRESH)
         act.connect('activate', self.__rebuild, False)
         ag.add_action(act)
@@ -946,13 +1138,14 @@ class QuodLibetWindow(Window, PersistentWindowMixin):
             first_action = first_action or act
             if name == current:
                 act.set_active(True)
-            ag.add_action(act)
+            ag.add_action_with_accel(act, None)
         assert first_action
+        self._browser_action = first_action
 
         def action_callback(view_action, current_action):
             current = browsers.name(
                 browsers.get(current_action.get_current_value()))
-            self.select_browser(view_action, current, library, player)
+            self._select_browser(view_action, current, library, player)
 
         first_action.connect("changed", action_callback)
 
@@ -989,12 +1182,32 @@ class QuodLibetWindow(Window, PersistentWindowMixin):
 
         return ui
 
-    def __show_about(self, player):
-        about = AboutQuodLibet(self, player)
+    def __show_about(self, *args):
+        about = AboutDialog(self, app)
         about.run()
         about.destroy()
 
-    def select_browser(self, activator, current, library, player,
+    def select_browser(self, browser_key, library, player):
+        """Given a browser name (see browsers.get()) changes the current
+        browser.
+
+        Returns True if the passed browser ID is known and the change
+        was initiated.
+        """
+
+        try:
+            Browser = browsers.get(browser_key)
+        except ValueError:
+            return False
+
+        action_name = "View%s" % Browser.__name__
+        for i, action in enumerate(self._browser_action.get_group()):
+            if action.get_name() == action_name:
+                action.set_active(True)
+                return True
+        return False
+
+    def _select_browser(self, activator, current, library, player,
                        restore=False):
 
         Browser = browsers.get(current)
@@ -1050,8 +1263,8 @@ class QuodLibetWindow(Window, PersistentWindowMixin):
         image.set_from_icon_name(icon, Gtk.IconSize.MENU)
 
     def __song_ended(self, player, song, stopped):
-        # check if the song should be removed base on the
-        # active filter of the current browser
+        # Check if the song should be removed, based on the
+        # active filter of the current browser.
         active_filter = self.browser.active_filter
         if song and active_filter and not active_filter(song):
             iter_ = self.songlist.model.find(song)
@@ -1330,8 +1543,7 @@ class QuodLibetWindow(Window, PersistentWindowMixin):
             self.browser.activate()
 
     def __set_time(self, info, songs):
-        i = len(songs)
         length = sum(song.get("~#length", 0) for song in songs)
-        t = self.browser.statusbar(i) % {
-            'count': i, 'time': util.format_time_long(length)}
+        t = self.browser.status_text(count=len(songs),
+                                     time=util.format_time_long(length))
         self.statusbar.set_default_text(t)
