@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2005 Joe Wreschnig
 #           2012 Christoph Reiter
 #      2011-2014 Nick Boultbee
@@ -9,16 +10,15 @@
 
 import time
 import datetime
-from collections import deque
 
 from gi.repository import Gtk, Pango, GLib
 
 from quodlibet import util
 from quodlibet import config
-from quodlibet import const
-from quodlibet.parse import Pattern
+from quodlibet.pattern import Pattern
 from quodlibet.qltk.views import TreeViewColumnButton
-from quodlibet.util.path import fsdecode, unexpand
+from quodlibet.qltk import add_css
+from quodlibet.util.path import fsdecode, unexpand, fsnative
 from quodlibet.formats._audio import FILESYSTEM_TAGS
 
 
@@ -37,7 +37,7 @@ def create_songlist_column(t):
         return NumericColumn(t)
     elif t in FILESYSTEM_TAGS:
         return FSColumn(t)
-    elif t.startswith("<"):
+    elif "<" in t:
         return PatternColumn(t)
     elif "~" not in t and t != "title":
         return NonSynthTextColumn(t)
@@ -45,6 +45,60 @@ def create_songlist_column(t):
         return WideTextColumn(t)
 
 
+def _highlight_current_cell(cr, background_area, cell_area, flags):
+    """Draws a 'highlighting' background for the cell. Look depends on
+    the active theme.
+    """
+
+    # Use drawing code/CSS for Entry (reason being that it looks best here)
+    dummy_widget = Gtk.Entry()
+    style_context = dummy_widget.get_style_context()
+    style_context.save()
+    # Make it less prominent
+    state = Gtk.StateFlags.INSENSITIVE | Gtk.StateFlags.BACKDROP
+    style_context.set_state(state)
+    color = style_context.get_border_color(state)
+    add_css(dummy_widget,
+            "* { border-color: rgba(%d, %d, %d, 0.3); }" % (
+                    color.red * 255, color.green * 255, color.blue * 255))
+    ba = background_area
+    ca = cell_area
+    # Draw over the left and right border so we don't see the rounded corners
+    # and borders. Use height for the overshoot as rounded corners + border
+    # should never be larger than the height..
+    # Ideally we would draw over the whole background but the cell area only
+    # redraws the cell_area so we get leftover artifacts if we draw
+    # above/below.
+    draw_area = (ba.x - ca.height, ca.y,
+                 ba.width + ca.height * 2, ca.height)
+    cr.save()
+    cr.new_path()
+    cr.rectangle(ba.x, ca.y, ba.width, ca.height)
+    cr.clip()
+    Gtk.render_background(style_context, cr, *draw_area)
+    Gtk.render_frame(style_context, cr, *draw_area)
+    cr.restore()
+    style_context.restore()
+
+
+class SongListCellAreaBox(Gtk.CellAreaBox):
+
+    highlight = False
+
+    def do_render(self, context, widget, cr, background_area, cell_area,
+                  flags, paint_focus):
+        if self.highlight and not flags & Gtk.CellRendererState.SELECTED:
+            _highlight_current_cell(cr, background_area, cell_area, flags)
+        return Gtk.CellAreaBox.do_render(
+            self, context, widget, cr, background_area, cell_area,
+            flags, paint_focus)
+
+    def do_apply_attributes(self, tree_model, iter_, is_expander, is_expanded):
+        self.highlight = tree_model.get_path(iter_) == tree_model.current_path
+        return Gtk.CellAreaBox.do_apply_attributes(
+            self, tree_model, iter_, is_expander, is_expanded)
+
+
 class SongListColumn(TreeViewColumnButton):
 
     __last_rendered = None
@@ -53,7 +107,8 @@ class SongListColumn(TreeViewColumnButton):
         """tag e.g. 'artist'"""
 
         title = self._format_title(tag)
-        super(SongListColumn, self).__init__(title)
+        super(SongListColumn, self).__init__(
+            title=title, cell_area=SongListCellAreaBox())
         self.set_tooltip_text(title)
         self.header_name = tag
 
@@ -69,7 +124,7 @@ class SongListColumn(TreeViewColumnButton):
     def _needs_update(self, value):
         """Call to check if the last passed value was the same.
 
-        This is used to reduce formating if the input is the same
+        This is used to reduce formatting if the input is the same
         either because of redraws or all columns have the same value
         """
 
@@ -82,8 +137,6 @@ class SongListColumn(TreeViewColumnButton):
 class TextColumn(SongListColumn):
     """Base text column"""
 
-    __label = Gtk.Label().create_pango_layout("")
-
     def __init__(self, tag):
         super(TextColumn, self).__init__(tag)
 
@@ -93,6 +146,10 @@ class TextColumn(SongListColumn):
 
         self.set_clickable(True)
 
+    @util.cached_property
+    def _layout(self):
+        return Gtk.Label().create_pango_layout("")
+
     def _cell_width(self, text, pad=8):
         """Returns the column width needed for the passed text"""
 
@@ -100,8 +157,8 @@ class TextColumn(SongListColumn):
         return self._text_width(text) + pad + cell_pad
 
     def _text_width(self, text):
-        self.__label.set_text(text, -1)
-        return self.__label.get_pixel_size()[0]
+        self._layout.set_text(text, -1)
+        return self._layout.get_pixel_size()[0]
 
     def _cdf(self, column, cell, model, iter_, user_data):
         """CellRenderer cell_data_func"""
@@ -124,10 +181,15 @@ class RatingColumn(TextColumn):
         self.set_min_width(width)
 
     def _cdf(self, column, cell, model, iter_, user_data):
-        value = model.get_value(iter_).get(
-            "~#rating", config.RATINGS.default)
-        if not self._needs_update(value):
+        song = model.get_value(iter_)
+        rating = song.get("~#rating")
+        default = config.RATINGS.default
+
+        if not self._needs_update((rating, default)):
             return
+
+        cell.set_sensitive(rating is not None)
+        value = rating if rating is not None else default
         cell.set_property('text', util.format_rating(value))
 
 
@@ -170,7 +232,8 @@ class DateColumn(WideTextColumn):
             else:
                 format_ = "%x"
             stamp = time.localtime(stamp)
-            text = time.strftime(format_, stamp).decode(const.ENCODING)
+            encoding = util.get_locale_encoding()
+            text = time.strftime(format_, stamp).decode(encoding)
             cell.set_property('text', text)
 
 
@@ -196,10 +259,11 @@ class FSColumn(WideTextColumn):
         self._render.set_property('ellipsize', Pango.EllipsizeMode.MIDDLE)
 
     def _cdf(self, column, cell, model, iter_, user_data):
-        value = model.get_value(iter_).comma(self.header_name)
+        values = model.get_value(iter_).list(self.header_name)
+        value = values[0] if values else fsnative(u"")
         if not self._needs_update(value):
             return
-        cell.set_property('text', unexpand(fsdecode(value)))
+        cell.set_property('text', fsdecode(unexpand(value)))
 
 
 class PatternColumn(WideTextColumn):
@@ -285,14 +349,13 @@ class NumericColumn(TextColumn):
 
         # resize if too small or way too big and above the minimum
         width = self.get_width()
-        max_width = max(self._texts.values() or [width])
-        if width < max_width:
-            self.set_fixed_width(max_width)
-            self.set_min_width(max_width)
-        elif (width - max_width >= self._single_char_width and
-                max_width >= self.__min_width):
-            self.set_fixed_width(max_width)
-            self.set_max_width(max_width)
+        needed_width = max([self.__min_width] + self._texts.values())
+        if width < needed_width:
+            self.set_fixed_width(needed_width)
+            self.set_min_width(needed_width)
+        elif width - needed_width >= self._single_char_width:
+            self.set_fixed_width(needed_width)
+            self.set_max_width(needed_width)
 
     def _recalc_width(self, path, text):
         self._texts[path[0]] = text
@@ -310,13 +373,13 @@ class LengthColumn(NumericColumn):
 
     def _get_min_width(self):
         # 1:22:22, allows entire albums as files (< 75mins)
-        return self._cell_width(util.format_time(60 * 82 + 22))
+        return self._cell_width(util.format_time_display(60 * 82 + 22))
 
     def _cdf(self, column, cell, model, iter_, user_data):
         value = model.get_value(iter_).get("~#length", 0)
         if not self._needs_update(value):
             return
-        text = util.format_time(value)
+        text = util.format_time_display(value)
         cell.set_property('text', text)
         self._recalc_width(model.get_path(iter_), text)
 
