@@ -108,7 +108,9 @@ class Window(Gtk.Window):
 
     def set_default_size(self, width, height):
         # https://bugzilla.gnome.org/show_bug.cgi?id=740922
-        if self._header_bar:
+        if self._header_bar and gtk_version < (3, 19):
+            # fixed with 3.20:
+            #   https://bugzilla.gnome.org/show_bug.cgi?id=756618
             if width != -1:
                 width += min((width - 174), 56)
             if height != -1:
@@ -328,16 +330,15 @@ class PersistentWindowMixin(object):
         # to QL remembering the wrong size. Work around that by waiting
         # until configure-event settles down, at which point the maximized
         # state should be set
-        # WARNING: we can't keep the event, because PyGObject doesn't
-        # keep it alive; so extract width/height before returning here.
 
-        self.__save_size_pos_deferred(event.width, event.height)
+        self.__save_size_pos_deferred()
         return False
 
-    def __do_save_size_pos(self, width, height):
+    def __do_save_size_pos(self):
         if self.__state & Gdk.WindowState.MAXIMIZED:
             return
 
+        width, height = self.get_size()
         value = "%d %d" % (width, height)
         config.set("memory", self.__conf("size"), value)
 
