@@ -11,7 +11,8 @@ import atexit
 import subprocess
 from quodlibet.compat import PY3
 from quodlibet.util.dprint import Colorise, print_
-from quodlibet.util.path import fsnative, is_fsnative
+from quodlibet.util.path import fsnative, is_fsnative, xdg_get_cache_home
+from quodlibet.util.misc import environ
 
 from unittest import TestCase as OrigTestCase
 
@@ -102,7 +103,7 @@ def init_fake_app():
     from quodlibet.player.nullbe import NullPlayer
     from quodlibet.library.libraries import SongFileLibrary
     from quodlibet.library.librarians import SongLibrarian
-    from quodlibet.qltk.quodlibetwindow import QuodLibetWindow
+    from quodlibet.qltk.quodlibetwindow import QuodLibetWindow, PlayerOptions
     from quodlibet.util.cover import CoverManager
 
     browsers.init()
@@ -113,6 +114,7 @@ def init_fake_app():
     app.library.librarian = SongLibrarian()
     app.cover_manager = CoverManager()
     app.window = QuodLibetWindow(app.library, app.player, headless=True)
+    app.player_options = PlayerOptions(app.window)
 
 
 def destroy_fake_app():
@@ -186,7 +188,7 @@ class Runner(object):
         result = Result(test.__name__, len(suite._tests), failfast=failfast)
         suite(result)
         result.printErrors()
-        return len(result.failures), len(result.errors)
+        return len(result.failures), len(result.errors), len(suite._tests)
 
 
 _BUS_INFO = None
@@ -207,16 +209,21 @@ def init_test_environ():
     # needed for dbus/dconf
     runtime_dir = tempfile.mkdtemp(prefix=fsnative(u"RUNTIME-"), dir=_TEMP_DIR)
     os.chmod(runtime_dir, 0o700)
-    os.environ["XDG_RUNTIME_DIR"] = runtime_dir
+    environ["XDG_RUNTIME_DIR"] = runtime_dir
+
+    # force the old cache dir so that GStreamer can re-use the GstRegistry
+    # cache file
+    environ["XDG_CACHE_HOME"] = xdg_get_cache_home()
 
     # set HOME and remove all XDG vars that default to it if not set
     home_dir = tempfile.mkdtemp(prefix=fsnative(u"HOME-"), dir=_TEMP_DIR)
-    os.environ["HOME"] = home_dir
-    os.environ.pop("XDG_DATA_HOME", None)
-    os.environ.pop("XDG_CACHE_HOME", None)
+    environ["HOME"] = home_dir
+
+    # set to new default
+    environ.pop("XDG_DATA_HOME", None)
 
     _BUS_INFO = None
-    if os.name != "nt" and "DBUS_SESSION_BUS_ADDRESS" in os.environ:
+    if os.name != "nt" and "DBUS_SESSION_BUS_ADDRESS" in environ:
         try:
             out = subprocess.check_output(["dbus-launch"])
         except (subprocess.CalledProcessError, OSError):
@@ -225,7 +232,7 @@ def init_test_environ():
             if PY3:
                 out = out.decode("ascii")
             _BUS_INFO = dict([l.split("=", 1) for l in out.splitlines()])
-            os.environ.update(_BUS_INFO)
+            environ.update(_BUS_INFO)
 
     # Ideally nothing should touch the FS on import, but we do atm..
     # Get rid of all modules so QUODLIBET_USERDIR gets used everywhere.
@@ -234,7 +241,8 @@ def init_test_environ():
             del(sys.modules[key])
 
     import quodlibet
-    quodlibet.init(no_translations=True)
+    quodlibet.init(no_translations=True, no_excepthook=True)
+    quodlibet.app.name = "QL Tests"
 
 
 def exit_test_environ():
@@ -330,17 +338,18 @@ def unit(run=[], filter_func=None, main=False, subdirs=None,
     import quodlibet.config
 
     runner = Runner()
-    failures = errors = 0
+    failures = errors = all_ = 0
     use_suites = filter(filter_func, suites)
     for test in sorted(use_suites, key=repr):
         if (not run
                 or test.__name__ in run
                 or test.__module__[11:] in run):
-            df, de = runner.run(test, failfast=stop_first)
-            if stop_first and (df or de):
-                break
+            df, de, num = runner.run(test, failfast=stop_first)
             failures += df
             errors += de
+            all_ += num
+            if stop_first and (df or de):
+                break
             quodlibet.config.quit()
 
-    return failures, errors
+    return failures, errors, all_
