@@ -7,7 +7,7 @@
 
 import sys
 
-from gi.repository import Gtk, Gdk, GdkPixbuf
+from gi.repository import GdkPixbuf
 from quodlibet import config
 from tests.plugin import PluginTestCase, init_fake_app, destroy_fake_app
 from tests import skipIf
@@ -36,12 +36,14 @@ class TTrayIcon(PluginTestCase):
 
     def test_popup_menu(self):
         self.plugin.enabled()
-        self.plugin._popup_menu(self.plugin._icon, Gdk.BUTTON_SECONDARY,
-                                Gtk.get_current_event_time())
-        self.plugin.disabled()
+        try:
+            self.plugin._tray.popup_menu()
+        finally:
+            self.plugin.disabled()
 
     def test_get_paused_pixbuf(self):
-        get_paused_pixbuf = self.modules["Tray Icon"].get_paused_pixbuf
+        get_paused_pixbuf = \
+            self.modules["Tray Icon"].systemtray.get_paused_pixbuf
 
         self.assertTrue(get_paused_pixbuf((1, 1), 0))
         self.assertRaises(ValueError, get_paused_pixbuf, (0, 0), 0)
@@ -49,7 +51,7 @@ class TTrayIcon(PluginTestCase):
 
     def test_new_with_paused_emblem(self):
         new_with_paused_emblem = \
-            self.modules["Tray Icon"].new_with_paused_emblem
+            self.modules["Tray Icon"].systemtray.new_with_paused_emblem
 
         # too small source pixbuf
         for w, h in [(150, 1), (1, 150), (1, 1)]:
