@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from tests import TestCase
-from helper import realized
+from .helper import realized
 
 from gi.repository import Gtk
 
@@ -36,7 +36,6 @@ SONGS = [
     AudioFile({
         "title": "xxx", "~filename": fsnative(u"/bin/bar"), "foo": "bar"}),
 ]
-SONGS.sort()
 
 UNKNOWN_ARTIST = AudioFile(dict(SONGS[0]))
 del UNKNOWN_ARTIST["artist"]
@@ -163,7 +162,7 @@ class TPaneConfig(TestCase):
         self.failUnlessEqual(p.title, "Title")
         self.failUnlessEqual(p.tags, {"title"})
 
-        self.failUnlessEqual(p.format(SONGS[0]), ["three"])
+        self.failUnlessEqual(p.format(SONGS[0]), [("three", "three")])
         self.failUnless(str(len(ALBUM.songs)) in p.format_display(ALBUM))
         self.failIf(p.has_markup)
 
@@ -172,7 +171,7 @@ class TPaneConfig(TestCase):
         self.failUnlessEqual(p.title, "Last Played")
         self.failUnlessEqual(p.tags, {"~#lastplayed"})
 
-        self.failUnlessEqual(p.format(SONGS[0]), ["0"])
+        self.failUnlessEqual(p.format(SONGS[0]), [("0", "0")])
         self.failIf(p.has_markup)
 
     def test_tied(self):
@@ -180,7 +179,8 @@ class TPaneConfig(TestCase):
         self.failUnlessEqual(p.title, "Title / Artist")
         self.failUnlessEqual(p.tags, {"title", "artist"})
 
-        self.failUnlessEqual(p.format(SONGS[0]), ["three - boris"])
+        self.failUnlessEqual(p.format(SONGS[0]),
+                             [("three", "three"), ("boris", "boris")])
         self.failIf(p.has_markup)
 
     def test_pattern(self):
@@ -212,7 +212,7 @@ class TPaneConfig(TestCase):
 class TPaneEntry(TestCase):
 
     def test_all_have(self):
-        sel = SongsEntry("foo", SONGS)
+        sel = SongsEntry("foo", "foo", SONGS)
         self.assertFalse(sel.all_have("artist", "one"))
         self.assertFalse(sel.all_have("~#mtime", 4))
         self.assertTrue(sel.all_have("foo", "bar"))
@@ -237,7 +237,7 @@ class TPaneEntry(TestCase):
         repr(entry)
 
     def test_songs(self):
-        entry = SongsEntry("key", SONGS)
+        entry = SongsEntry("key", "key", SONGS)
         self.assertEqual(entry.key, "key")
         conf = PaneConfig("title:artist")
         self.assertTrue("boris" in entry.get_count_text(conf))
@@ -246,7 +246,7 @@ class TPaneEntry(TestCase):
         repr(entry)
 
     def test_songs_markup(self):
-        entry = SongsEntry("key", SONGS)
+        entry = SongsEntry("key", "key", SONGS)
         conf = PaneConfig("<title>")
         self.assertEqual(entry.get_text(conf), (True, "key"))
 
