@@ -5,6 +5,7 @@ import os
 
 from quodlibet import config
 from quodlibet.util.path import is_fsnative, fsnative, fsdecode
+from quodlibet.compat import PY2
 from quodlibet.formats import AudioFile
 from quodlibet.formats._audio import INTERN_NUM_DEFAULT
 from quodlibet.formats import decode_value
@@ -18,6 +19,7 @@ bar_1_1 = AudioFile({
 bar_1_2 = AudioFile({
     "~filename": fsnative(u"/fakepath/2"),
     "title": "Perhaps another",
+    "titlesort": "Titles don't sort",
     "discnumber": "1", "tracknumber": "2/3",
     "artist": "Lali-ho!", "album": "Bar",
     "date": "2004-12-12", "originaldate": "2005-01-01",
@@ -26,13 +28,16 @@ bar_2_1 = AudioFile({
     "~filename": fsnative(u"does not/exist"),
     "title": "more songs",
     "discnumber": "2/2", "tracknumber": "1",
-    "artist": "Foo\nI have two artists", "album": "Bar",
+    "artist": "Foo\nI have two artists",
+    "artistsort": "Foosort\n\nThird artist",
+    "album": "Bar",
     "lyricist": "Foo", "composer": "Foo", "performer": "I have two artists"})
 bar_va = AudioFile({
     "~filename": "/fakepath/3",
     "title": "latest",
     "artist": "Foo\nI have two artists",
     "album": "Bar",
+    "language": "de\neng",
     "albumartist": "Various Artists",
     "performer": "Jay-Z"})
 
@@ -47,7 +52,7 @@ num_call = AudioFile({"custom": "0.3"})
 class TAudioFile(TestCase):
     def setUp(self):
         config.RATINGS = config.HardCodedRatingsPrefs()
-        file(quux["~filename"], "w")
+        open(quux["~filename"], "w").close()
 
     def test_sort(self):
         l = [quux, bar_1_2, bar_2_1, bar_1_1]
@@ -67,6 +72,12 @@ class TAudioFile(TestCase):
             list(quux.iterrealitems()),
             [('album', u'Quuxly')])
 
+    def test_language(self):
+        self.assertEqual(bar_va("~language"), "German\nEnglish")
+        self.assertEqual(bar_va.list("~language"), ['German', 'English'])
+        self.assertEqual(bar_1_1("~language", default="foo"), "foo")
+        self.assertEqual(bar_1_1.list("~language"), [])
+
     def test_trackdisc(self):
         self.failUnlessEqual(bar_1_1("~#track"), 1)
         self.failUnlessEqual(bar_1_1("~#disc"), 1)
@@ -151,20 +162,75 @@ class TAudioFile(TestCase):
         self.failUnlessEqual(bar_2_1.list("artist"),
                              bar_2_1["artist"].split("\n"))
 
+    def test_list_sort(self):
+        self.failUnlessEqual(bar_1_1.list_sort("title"),
+                             [("A song", "A song")])
+        self.failUnlessEqual(bar_1_1.list_sort("artist"),
+                             [("Foo", "Foo")])
+
+        self.failUnlessEqual(quux.list_sort("artist"), [])
+        self.failUnlessEqual(quux.list_sort("title"),
+                             [(quux("title"), quux("title"))])
+        self.failUnlessEqual(quux.list_sort("not a key"), [])
+
+        self.failUnlessEqual(bar_1_2.list_sort("title"),
+                             [("Perhaps another", "Perhaps another")])
+        self.failUnlessEqual(bar_2_1.list_sort("artist"),
+                             [("Foo", "Foosort"),
+                              ("I have two artists", "I have two artists")])
+        self.failUnlessEqual(bar_2_1.list_sort("~#track"),
+                             [('1', '1')])
+
+    def test_list_sort_empty_sort(self):
+        # we don't want to care about empty sort values, make sure we ignore
+        # them
+        s = AudioFile({"artist": "x\ny\nz", "artistsort": "c\n\nd"})
+        self.assertEqual(
+            s.list_sort("artist"), [("x", "c"), ("y", "y"), ("z", "d")])
+
+    def test_list_sort_noexist(self):
+        self.failUnlessEqual(bar_1_1.list_sort("nopenopenope"), [])
+
+    def test_list_separate_noexist(self):
+        self.failUnlessEqual(bar_1_1.list_separate("nopenopenope"), [])
+
+    def test_list_sort_length_diff(self):
+        s = AudioFile({"artist": "a\nb", "artistsort": "c"})
+        self.assertEqual(s.list_sort("artist"), [("a", "c"), ("b", "b")])
+
+        s = AudioFile({"artist": "a\nb", "artistsort": "c\nd\ne"})
+        self.assertEqual(s.list_sort("artist"), [("a", "c"), ("b", "d")])
+
+        s = AudioFile({"artistsort": "c\nd\ne"})
+        self.assertEqual(s.list_sort("artist"), [])
+
+        s = AudioFile({"artist": "a\nb"})
+        self.assertEqual(s.list_sort("artist"), [("a", "a"), ("b", "b")])
+
+        s = AudioFile({})
+        self.assertEqual(s.list_sort("artist"), [])
+
     def test_list_separate(self):
-        for key in bar_1_1.realkeys():
-            self.failUnlessEqual(bar_1_1.list_separate(key), [bar_1_1(key)])
+        self.failUnlessEqual(bar_1_1.list_separate("title"),
+                             [("A song", "A song")])
+        self.failUnlessEqual(bar_1_1.list_separate("artist"),
+                             [("Foo", "Foo")])
 
         self.failUnlessEqual(bar_2_1.list_separate("~artist~album"),
-                             ['Foo - Bar', 'I have two artists - Bar'])
+                             [('Foo', 'Foosort'),
+                              ('I have two artists', 'I have two artists'),
+                              ('Bar', 'Bar')])
 
         self.failUnlessEqual(bar_2_1.list_separate("~artist~~#track"),
-                             ['Foo - 1', 'I have two artists - 1'])
+                             [('Foo', 'Foosort'),
+                              ('I have two artists', 'I have two artists'),
+                              ('1', '1')])
 
     def test_list_list_separate_types(self):
         res = bar_2_1.list_separate("~~#track~artist~~filename")
-        self.assertEqual(res, [u'1 - Foo - does not/exist',
-                               u'1 - I have two artists - does not/exist'])
+        self.assertEqual(res, [(u'1', u'1'), (u'Foo', u'Foosort'),
+                               (u'I have two artists', u'I have two artists'),
+                               (u'does not/exist', u'does not/exist')])
 
     def test_comma(self):
         for key in bar_1_1.realkeys():
@@ -203,9 +269,9 @@ class TAudioFile(TestCase):
 
     def test_is_writable(self):
         self.assertTrue(quux.is_writable())
-        os.chmod(quux["~filename"], 0444)
+        os.chmod(quux["~filename"], 0o444)
         self.assertFalse(quux.is_writable())
-        os.chmod(quux["~filename"], 0644)
+        os.chmod(quux["~filename"], 0o644)
         self.assertTrue(quux.is_writable())
 
     def test_can_multiple_values(self):
@@ -378,8 +444,10 @@ class TAudioFile(TestCase):
         self.failUnless(set(dump.split("\n")) == set(n.to_dump().split("\n")))
 
     def test_to_dump_long(self):
+        if not PY2:
+            return
         b = AudioFile(bar_1_1)
-        b["~#length"] = 200000000000L
+        b["~#length"] = long(200000000000)
         dump = b.to_dump()
         num = len(set(bar_1_1.keys()) | INTERN_NUM_DEFAULT)
         self.failUnlessEqual(dump.count("\n"), num + 2)
@@ -489,16 +557,34 @@ class TAudioFile(TestCase):
         self.failUnlessRaises(
             ValueError, setattr, AudioFile(), 'bookmarks', [(-1, "!")])
 
+    def test_has_rating(self):
+        song = AudioFile()
+        self.assertFalse(song.has_rating)
+        song["~#rating"] = 0.5
+        self.assertTrue(song.has_rating)
+        song.remove_rating()
+        self.assertFalse(song.has_rating)
+
+    def test_remove_rating(self):
+        song = AudioFile()
+        self.assertFalse(song.has_rating)
+        song.remove_rating()
+        self.assertFalse(song.has_rating)
+        song["~#rating"] = 0.5
+        self.assertTrue(song.has_rating)
+        song.remove_rating()
+        self.assertFalse(song.has_rating)
+
     def test_album_key(self):
         album_key_tests = [
-            ({}, ('', '', '')),
-            ({'album': 'foo'}, (('foo',), '', '')),
-            ({'labelid': 'foo'}, ('', '', 'foo')),
-            ({'musicbrainz_albumid': 'foo'}, ('', '', 'foo')),
-            ({'album': 'foo', 'labelid': 'bar'}, (('foo',), '', 'bar')),
+            ({}, ((), (), '')),
+            ({'album': 'foo'}, (('foo',), (), '')),
+            ({'labelid': 'foo'}, ((), (), 'foo')),
+            ({'musicbrainz_albumid': 'foo'}, ((), (), 'foo')),
+            ({'album': 'foo', 'labelid': 'bar'}, (('foo',), (), 'bar')),
             ({'album': 'foo', 'labelid': 'bar', 'musicbrainz_albumid': 'quux'},
-                (('foo',), '', 'bar')),
-            ({'albumartist': 'a'}, ('', ('a',), '')),
+                (('foo',), (), 'bar')),
+            ({'albumartist': 'a'}, ((), ('a',), '')),
             ]
         for tags, expected in album_key_tests:
             afile = AudioFile(**tags)
