@@ -1,17 +1,20 @@
 # -*- coding: utf-8 -*-
-from tests import TestCase
+from tests import TestCase, init_fake_app, destroy_fake_app
 
-from gi.repository import Gtk
-
-from quodlibet.player.nullbe import NullPlayer
+from quodlibet import app
 from quodlibet.mmkeys import MMKeysHandler, iter_backends
 
 
 class TMmKeys(TestCase):
 
+    def setUp(self):
+        init_fake_app()
+
+    def tearDown(self):
+        destroy_fake_app()
+
     def test_handler(self):
-        win = Gtk.Window()
-        handler = MMKeysHandler("Foo", win, NullPlayer())
+        handler = MMKeysHandler(app)
         handler.quit()
 
     def test_backends(self):
