@@ -29,6 +29,7 @@ class TQuery_is_valid(TestCase):
         self.failUnless(Query.is_valid('t = |(tag, bar)'))
         self.failUnless(Query.is_valid('t = a"tag"'))
         self.failIf(Query.is_valid('t = a, tag'))
+        self.failUnless(Query.is_valid('tag with spaces = tag'))
 
     def test_empty(self):
         self.failUnless(Query.is_valid(''))
@@ -87,6 +88,11 @@ class TQuery_is_valid(TestCase):
         self.failIf(Query.is_valid("#(t !> 3)"))
         self.failIf(Query.is_valid("#(t >> 3)"))
 
+    def test_numcmp_func(self):
+        self.assertTrue(Query.is_valid("#(t:min < 3)"))
+        self.assertTrue(
+            Query.is_valid("&(#(playcount:min = 0), #(added < 1 month ago))"))
+
     def test_trinary(self):
         self.failUnless(Query.is_valid("#(2 < t < 3)"))
         self.failUnless(Query.is_valid("#(2 >= t > 3)"))
@@ -102,6 +108,44 @@ class TQuery_is_valid(TestCase):
     def test_nesting(self):
         self.failUnless(Query.is_valid("|(s, t = &(/a/, /b/),!#(2 > q > 3))"))
 
+    def test_extension(self):
+        self.failUnless(Query.is_valid("@(name)"))
+        self.failUnless(Query.is_valid("@(name: extension body)"))
+        self.failUnless(Query.is_valid("@(name: body (with (nested) parens))"))
+        self.failUnless(Query.is_valid(r"@(name: body \\ with \) escapes)"))
+
+        self.failIf(Query.is_valid("@()"))
+        self.failIf(Query.is_valid(r"@(invalid %name!\\)"))
+        self.failIf(Query.is_valid("@(name: mismatched ( parenthesis)"))
+        self.failIf(Query.is_valid(r"@(\()"))
+        self.failIf(Query.is_valid("@(name:unclosed body"))
+        self.failIf(Query.is_valid("@ )"))
+
+    def test_numexpr(self):
+        self.failUnless(Query.is_valid("#(t < 3*4)"))
+        self.failUnless(Query.is_valid("#(t * (1+r) < 7)"))
+        self.failUnless(Query.is_valid("#(0 = t)"))
+        self.failUnless(Query.is_valid("#(t < r < 9)"))
+        self.failUnless(Query.is_valid("#((t-9)*r < -(6*2) = g*g-1)"))
+        self.failUnless(Query.is_valid("#(t + 1 + 2 + -4 * 9 > g*(r/4 + 6))"))
+        self.failUnless(Query.is_valid("#(date < 2010-4)"))
+        self.failUnless(Query.is_valid("#(date < 2010 - 4)"))
+        self.failUnless(Query.is_valid("#(date > 0000)"))
+        self.failUnless(Query.is_valid("#(date > 00004)"))
+        self.failUnless(Query.is_valid("#(t > 3 minutes)"))
+        self.failUnless(Query.is_valid("#(added > today)"))
+        self.failUnless(Query.is_valid("#(length < 5:00)"))
+        self.failUnless(Query.is_valid("#(filesize > 5M)"))
+        self.failUnless(Query.is_valid("#(added < 7 days ago)"))
+
+        self.failIf(Query.is_valid("#(3*4)"))
+        self.failIf(Query.is_valid("#(t = 3 + )"))
+        self.failIf(Query.is_valid("#(t = -)"))
+        self.failIf(Query.is_valid("#(-4 <)"))
+        self.failIf(Query.is_valid("#(t < ()"))
+        self.failIf(Query.is_valid("#((t +) - 1 > 8)"))
+        self.failIf(Query.is_valid("#(t += 8)"))
+
 
 class TQuery(TestCase):
 
@@ -109,7 +153,9 @@ class TQuery(TestCase):
         config.init()
         self.s1 = AudioFile(
             {"album": "I Hate: Tests", "artist": "piman", "title": "Quuxly",
-             "version": "cake mix", "~filename": "/dir1/foobar.ogg"})
+             "version": "cake mix", "~filename": "/dir1/foobar.ogg",
+             "~#length": 224, "~#skipcount": 13, "~#playcount": 24,
+             "date": "2007-05-24"})
         self.s2 = AudioFile(
             {"album": "Foo the Bar", "artist": "mu", "title": "Rockin' Out",
              "~filename": "/dir2/something.mp3", "tracknumber": "12/15"})
@@ -362,6 +408,34 @@ class TQuery(TestCase):
         # group refs unsupported for diacritic matching
         Query(u'/(<)?(\w+@\w+(?:\.\w+)+)(?(1)>)/d')
 
+    def test_numexpr(self):
+        self.failUnless(Query("#(length = 224)").search(self.s1))
+        self.failUnless(Query("#(length = 3:44)").search(self.s1))
+        self.failUnless(Query("#(length = 3 minutes + 44 seconds)")
+                        .search(self.s1))
+        self.failUnless(Query("#(playcount > skipcount)").search(self.s1))
+        self.failUnless(Query("#(playcount < 2 * skipcount)").search(self.s1))
+        self.failUnless(Query("#(length > 3 minutes)").search(self.s1))
+        self.failUnless(Query("#(3:00 < length < 4:00)").search(self.s1))
+        self.failUnless(Query("#(40 seconds < length/5 < 1 minute)")
+                        .search(self.s1))
+        self.failUnless(Query("#(2+3 * 5 = 17)").search(self.s1))
+
+        self.failIf(Query("#(track + 1 != 13)").search(self.s2))
+
+    def test_numexpr_date(self):
+        self.failUnless(Query("#(length < 2005-07-19)").search(self.s1))
+        self.failUnless(Query("#(date > 2005-07-19)").search(self.s1))
+        self.failUnless(Query("#(2005-11-24 < 2005-07-19)").search(self.s1))
+        self.failUnless(Query("#(date = (2007-05-19) + 5 days)")
+                        .search(self.s1))
+        self.failUnless(Query("#(date - 5 days = 2007-05-19)").search(self.s1))
+        self.failUnless(Query("#(2010-02-18 > date)").search(self.s1))
+        self.failUnless(Query("#(2010 > date)").search(self.s1))
+        self.failUnless(Query("#(date > 4)").search(self.s1))
+        self.failUnless(Query("#(date > 0004)").search(self.s1))
+        self.failUnless(Query("#(date > 0000)").search(self.s1))
+
 
 class TQuery_get_type(TestCase):
     def test_red(self):
